@@ -158,20 +158,22 @@ class WorkflowEngine:
             if filepath.__contains__(".flw"):
                 self.flowname = filepath.split("\\")[-1].replace(".flw", "")
                 with open(filepath, "rb") as binary_file:
+                    binary_file.seek(24)
                     # Read the whole file at once
                     content = binary_file.read()
                 str_content = content.decode("ascii", errors='ignore')
-                str_content = "".join([x for x in str_content if x != '' and x != '']).strip().strip('\x00')
-                remain =math.ceil((len(str_content)/4) - int(len(str_content)/4))
-                str_content = str_content[0:len(str_content)-remain]
-                idx = 0
-                if str_content.__contains__("fV0"):
-                    str_content = str_content.split("fV0")[0][1:] + "fV0==="
-                if str_content.__contains__("In1d"):
-                    if str_content.index("In1d") + 4 > idx:
-                        idx = str_content.index("In1d") + 4
-                if idx > 0:
-                    str_content = str_content[0:idx]
+                str_content = str_content[:-1]
+                # str_content = "".join([x for x in str_content if x != '' and x != '']).strip().strip('\x00')
+                # remain =math.ceil((len(str_content)/4) - int(len(str_content)/4))
+                # str_content = str_content[0:len(str_content)-remain]
+                # idx = 0
+                # if str_content.__contains__("fV0"):
+                #     str_content = str_content.split("fV0")[0][1:] + "fV0==="
+                # if str_content.__contains__("In1d"):
+                #     if str_content.index("In1d") + 4 > idx:
+                #         idx = str_content.index("In1d") + 4
+                # if idx > 0:
+                #     str_content = str_content[0:idx]
                 decoded = base64.b64decode(str_content).decode("ascii", errors='ignore')
                 dict_list = json.loads(decoded)
                 return dict_list
@@ -1666,5 +1668,4 @@ class Visio:
         properties.update({"type": str(properties["type"]).lower()})
         for k, v in properties.items():
             setattr(retn, k, v)
-        return retn
-
+        return retn
\ No newline at end of file
